<?php

/*
Plugin Name: Digiwoo
Plugin URI: https://digiwoo.de
Description: Use Digistore24 as your new Payment Gateway with WooCommerce!
Version: 1.0.2
Author: Hendrik Bäker
Author URI: https://baeker-it.de
License: GPL2
*/

if(in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
	define( 'DIGIWOO_PATH', plugin_dir_path( __FILE__ ) );
	define( 'DIGIWOO_CLASSES', plugin_dir_path( __FILE__ ) . '/includes/classes/' );
	define( 'DIGIWOO_VIEWS', plugin_dir_path( __FILE__ ) . '/includes/views/' );
	define( 'DIGIWOO_THANKYOU', '/digiwoo_accept_payment' );
	require_once( DIGIWOO_CLASSES . 'ds24_api.php' );

	add_action( 'woocommerce_api_wc_gateway_paypal', 'get_ipn' );

	add_filter( 'woocommerce_thankyou_order_received_text', 'digistore24_text' );

	if ( strpos($_SERVER['REQUEST_URI'], 'ipn_test') ) {
		require_once( DIGIWOO_CLASSES . 'ds24_ipn_receiver.php' );
	}

	function digistore24_text() {
		return 'Vielen Dank für Ihre Bestellung. Die Bezahlung wird durch unseren Partner Digistore24.com abgewickelt.';
	}

	add_action( 'woocommerce_thankyou', 'get_ipn' );
	function get_ipn() {
		require_once( DIGIWOO_CLASSES . 'ds24_ipn_receiver.php' );
	}

	require_once( DIGIWOO_CLASSES . 'WC_Gateway_Digiwoo.php' );
	if ( ! class_exists( 'Digiwoo' ) ) {
		class Digiwoo {

			private $url;

			public $digistore;

			private $product_id;

			private $tracking;

			private $buyer = array();

			private $placeholders = array();

			private $payment_plan = array();

			public $product_set = false;

			private $urls = [];

			const LICENSE_SECRET = '58944d3c303429.44633063';

			const LICENSE_REFERENCE = 'Digiwoo';

			const LICENSE_SERVER = 'http://oliverhees.com';

			function __construct() {
				$this->digistore = DigistoreApi::connect( get_option( 'digiwoo_api_key' ) );
				add_action( 'admin_init', [ $this, 'digiwoo_init' ] );
				add_action( 'admin_menu', [ $this, 'digiwoo_menu' ] );
				add_action( 'wp_ajax_digiwoo_activate_license', [ $this, 'activateLicense' ] );
					add_action( 'wp_ajax_digiwoo_init_digistore24_api', [ $this, 'digiwoo_init_digistore24_api' ] );
					add_action( 'wp_ajax_digiwoo_save_api_key', [ $this, 'digiwoo_save_api_key' ] );
					add_action( 'wp_ajax_digiwoo_create_test_url', [ $this, 'createUrl' ] );
					if ( is_numeric( get_option( 'digiwoo_product_id' ) ) ) {
						$this->product_id = get_option( 'digiwoo_product_id' );
					}
			}

			public function setCustomer( $customer = array() ) {
				$this->buyer = $customer;
			}

			public function setTracking( $order_id = 0 ) {
				$this->tracking = [
					'custom' => $order_id
				];
			}

			public function setProductInfo( $product ) {
				$this->placeholders['product_name'] .= ', ' . $product;
				$this->product_set                  = true;
			}

			public function setPrice( $price ) {
				$this->payment_plan = $price;
			}

			public function setUrl( $order_id ) {
				$order      = new WC_Order( $order_id );
				$this->urls = [
					'thankyou_url' => $order->get_checkout_order_received_url() . '&order_id=' . $order_id
				];
			}

			public function getFreeTransactions($action = '')
			{
				if(empty($action))
				{
					return false;
				}
				$status = get_option(date('mY', time()).'_DIGIWOO');
				if($status == null)
				{
					update_option(date('mY', time()).'_DIGIWOO', 1);
					return true;
				}
				if($status <= 4)
				{
					$status += 1;
					update_option(date('mY', time()).'_DIGIWOO', $status);
					return true;
				}
				return false;
			}

			public function digiwoo_init() {
				register_setting( 'digiwooSettings', 'digiwooSetting', 'digiwooValidate' );
			}

			public function digiwoo_menu() {
				add_menu_page( 'Digistore24 WooCommerce API Einstellungen', 'Digiwoo Einstellungen', 'delete_posts', 'digiwoo', [
					$this,
					'digiwoo_settings'
				], null, 3 );
			}

			public function digiwoo_settings() {
				include( DIGIWOO_VIEWS . 'settings.phtml' );
			}

			public function digiwoo_init_digistore24_api() {
				$products = $this->digistore->listProducts();
				if ( ! empty( $products->products[0] ) ) {
					update_option( 'digiwoo_product_id', $products->products[0]->id );
				}
				$product = $products->products[0];
				include( DIGIWOO_VIEWS . 'view_digistore_product.phtml' );
				wp_die();
			}

			public function digiwoo_save_api_key() {
				$key    = filter_input( INPUT_POST, 'key' );
				$update = update_option( 'digiwoo_api_key', $key );
				if ( $update ) {
					return json_encode( 'API Key gespeichert' );
				} else {
					return json_encode( 'Fehler beim Speichern des API Keys' );
				}
				wp_die();
			}

			public function createUrl( $woo = false, $customer = null, $placeholders = null, $payment_plan = null, $urls = null ) {
				try {
					if ( ! $woo ) {
						if ( $customer == null or $placeholders == null or $payment_plan == null or $urls == null ) {
							$this->buyer        = [
								'first_name'    => filter_input( INPUT_POST, 'first_name' ),
								'last_name'     => filter_input( INPUT_POST, 'last_name' ),
								'email'         => filter_input( INPUT_POST, 'email' ),
								'street'        => filter_input( INPUT_POST, 'street' ),
								'zipcode'       => filter_input( INPUT_POST, 'zipcode' ),
								'city'          => filter_input( INPUT_POST, 'city' ),
								'readonly_keys' => 'email_and_name'
							];
							$this->placeholders = [
								'product_name' => 'Testprodukt Digiwoo',
							];
							$this->payment_plan = [
								'first_amount' => 50.00,
								'currency'     => 'EUR'
							];
						} else {
							$this->buyer        = $customer;
							$this->placeholders = $placeholders;
							$this->payment_plan = $payment_plan;
							$this->urls         = $urls;
						}
						$data = $this->digistore->createBuyUrl(
							get_option( 'digiwoo_product_id' ),
							$this->buyer,
							[],
							[],
							[],
							[],
							$this->placeholders,
							[]
						);
					} else {
						$data = $this->digistore->createBuyUrl(
							get_option( 'digiwoo_product_id' ),
							$this->buyer,
							$this->payment_plan,
							$this->tracking,
							[],
							$this->urls,
							$this->placeholders,
							[]
						);
					}
					$this->url = $data->url;

					return [ 'result' => 'success', 'url' => $this->url ];
				} catch ( DigistoreApiException $e ) {
					return [ 'result' => 'failed', 'message' => json_encode( $e->getMessage() ) ];
				}
			}
		}
	}
	add_action( 'init', 'load_digiwoo' );

	function load_digiwoo() {
		return new digiwoo();
	}

	global $digiwoo;
}