<?php
add_action( 'plugins_loaded', 'init_digiwoo_class' );

function init_digiwoo_class() {
	if ( ! class_exists( 'WC_Gateway_Digiwoo' ) ) {
		class WC_Gateway_Digiwoo extends WC_Payment_Gateway {

			private $digiwoo;

			public function __construct() {
				$this->digiwoo            = new Digiwoo();
				$this->id                 = 'digiwoo';
				$this->has_fields         = false;
				$this->method_title       = 'Digistore24';
				$this->method_description = 'Use Digistore24 to get Paid';
				$this->supports           = [
					'products'
				];
				$this->init_form_fields();
				$this->init_settings();
				$this->title       = $this->get_option( 'title' );
				$this->description = $this->get_option( 'description' );
				add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, [
					$this,
					'process_admin_options'
				] );
			}

			public function init_form_fields() {
				$this->form_fields = [
					'enabled'     => [
						'title'   => __( 'Enable/Disable', 'woocommerce' ),
						'type'    => 'checkbox',
						'label'   => __( 'Enable Digistore24 Payment', 'woocommerce' ),
						'default' => 'yes'
					],
					'title'       => [
						'title'       => __( 'Title', 'woocommerce' ),
						'type'        => 'text',
						'description' => __( 'Zahlung über Digistore24' ),
						'default'     => __( 'Digistore24 Payment', 'woocommerce' ),
						'desc_tip'    => true,
					],
					'description' => [
						'title'   => __( 'Customer Message', 'woocommerce' ),
						'type'    => 'textarea',
						'default' => ''
					]
				];
			}

			public function process_payment( $order_id ) {
				if ( ! $this->digiwoo->getFreeTransactions( 'check' ) ) {
					try {
						global $woocommerce;
						$order    = new WC_Order( $order_id );
						$products = $order->get_items();
						$this->digiwoo->setCustomer( [
							'first_name'    => $order->billing_first_name,
							'last_name'     => $order->billing_last_name,
							'email'         => $order->billing_email,
							'street'        => $order->billing_address_1,
							'zipcode'       => $order->billing_postcode,
							'city'          => $order->billing_city,
							'readonly_keys' => 'email_and_name'
						] );
						foreach ( $products as $product ) {
							$this->digiwoo->setProductInfo( $product['name'] );
						}
						$this->digiwoo->setTracking( $order_id );
						$this->digiwoo->setPrice( [
							'first_amount' => (double) $order->get_total(),
							'currency'     => 'EUR'
						] );
						$this->digiwoo->setUrl( $order_id );
						$payment = $this->digiwoo->createUrl( true );

						return [
							'result'   => 'success',
							'redirect' => $payment['url']
						];
					} catch ( DigistoreApiException $e ) {
						wc_add_notice( $e->getMessage(), 'error' );
					}
				} else {
					wc_add_notice( 'Digiwoo ist nicht aktiv, bitte andere Zahlungsmethode wählen', 'error' );
				}
			}

		}
	}
}
add_filter( 'woocommerce_payment_gateways', 'register_digiwoo' );

function register_digiwoo( $methods ) {
	$methods[] = 'WC_Gateway_Digiwoo';

	return $methods;
}
?>